package proxy.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.List;

import com.google.common.collect.Lists;

class NbtList extends Nbt {
	private List<Nbt> list = Lists.newArrayList();
	private byte type = 0;

	void write(DataOutput output) throws IOException {
		this.type = this.list.isEmpty() ? 0 : this.list.get(0).getId();
		output.writeByte(this.type);
		output.writeInt(this.list.size());
		for(int z = 0; z < this.list.size(); z++) {
			this.list.get(z).write(output);
		}
	}

	void read(DataInput input, int depth, Tracker tracker) throws IOException {
		tracker.read(296L);
		if(depth > 512)
			throw new RuntimeException("Tried to read tag tree deeper than 512");
		this.type = input.readByte();
		int len = input.readInt();
		if(this.type == 0 && len > 0)
			throw new RuntimeException("Type null on list tag");
		tracker.read(32L * (long)len);
		this.list = Lists.newArrayListWithCapacity(len);
		for(int z = 0; z < len; z++) {
			Nbt nbtbase = Nbt.createTag(this.type);
			nbtbase.read(input, depth + 1, tracker);
			this.list.add(nbtbase);
		}
	}

	byte getId() {
		return (byte)9;
	}

	int getStringListLength() {
		return this.type != 8 && !this.list.isEmpty() ? -1 : this.list.size();
	}
}
