package proxy.packet;

import java.io.IOException;

import proxy.network.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S22PacketMultiBlockChange implements Packet<ProxyHandler>
{
    private int chunkPosCoordX;
    private int chunkPosCoordZ;
    private S22PacketMultiBlockChange.BlockUpdateData[] changedBlocks;

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.chunkPosCoordX = buf.readInt();
        this.chunkPosCoordZ = buf.readInt();
        this.changedBlocks = new S22PacketMultiBlockChange.BlockUpdateData[buf.readVarIntFromBuffer()];

        for (int i = 0; i < this.changedBlocks.length; ++i)
        {
            this.changedBlocks[i] = new S22PacketMultiBlockChange.BlockUpdateData(buf.readShort(), buf.readVarIntFromBuffer());
        }
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeInt(this.chunkPosCoordX);
        buf.writeInt(this.chunkPosCoordZ);
        buf.writeVarIntToBuffer(this.changedBlocks.length);

        for (S22PacketMultiBlockChange.BlockUpdateData s22packetmultiblockchange$blockupdatedata : this.changedBlocks)
        {
            buf.writeShort(s22packetmultiblockchange$blockupdatedata.func_180089_b());
            buf.writeVarIntToBuffer(s22packetmultiblockchange$blockupdatedata.getBlockState());
        }
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleMultiBlockChange(this);
    }

    public class BlockUpdateData
    {
        private final short chunkPosCrammed;
        private final int blockState;

        public BlockUpdateData(short p_i45984_2_, int state)
        {
            this.chunkPosCrammed = p_i45984_2_;
            this.blockState = state;
        }

        public short func_180089_b()
        {
            return this.chunkPosCrammed;
        }

        public int getBlockState()
        {
            return this.blockState;
        }
    }
}
