package proxy.packet;

import java.io.IOException;

import proxy.network.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;
import proxy.util.Stack;

public class S30PacketWindowItems implements Packet<ProxyHandler>
{
    private int windowId;
    private Stack[] itemStacks;

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.windowId = buf.readUnsignedByte();
        int i = buf.readShort();
        this.itemStacks = new Stack[i];

        for (int j = 0; j < i; ++j)
        {
            this.itemStacks[j] = buf.readStack();
        }
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeByte(this.windowId);
        buf.writeShort(this.itemStacks.length);

        for (Stack itemstack : this.itemStacks)
        {
            buf.writeStack(itemstack);
        }
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleWindowItems(this);
    }
}
