package proxy.packet;

import java.io.IOException;

import proxy.network.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;
import proxy.util.Vec3;
import proxy.util.Formatter;

public class S33PacketUpdateSign implements Packet<ProxyHandler>
{
    private Vec3 blockPos;
    private String[] lines;
    
    public S33PacketUpdateSign() {
    	
    }
    
    public S33PacketUpdateSign(int x, int y, int z, String line1, String line2, String line3, String line4) {
    	this.blockPos = new Vec3(x, y, z);
    	this.lines = new String[] {Formatter.toJsonString(line1), Formatter.toJsonString(line2), Formatter.toJsonString(line3), Formatter.toJsonString(line4)};
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.blockPos = buf.readVector();
        this.lines = new String[4];

        for (int i = 0; i < 4; ++i)
        {
            this.lines[i] = buf.readChatComponent();
        }
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeVector(this.blockPos);

        for (int i = 0; i < 4; ++i)
        {
            buf.writeChatComponent(this.lines[i]);
        }
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleUpdateSign(this);
    }
}
