package proxy.util;

import java.io.IOException;
import java.util.List;

import com.google.common.collect.Lists;

import proxy.network.PacketBuffer;

public class EntityData {
	private static class Vec3f {
		private final float x;
		private final float y;
		private final float z;

		public Vec3f(float x, float y, float z) {
			this.x = x;
			this.y = y;
			this.z = z;
		}

		public float getX() {
			return this.x;
		}

		public float getY() {
			return this.y;
		}

		public float getZ() {
			return this.z;
		}
	}
	
	private final int type;
	private final int id;
	private final Object data;

	private static void writeData(PacketBuffer buf, EntityData data) throws IOException {
		int value = (data.getType() << 5 | data.getId() & 31) & 255;
		buf.writeByte(value);
		switch(data.getType()) {
			case 0:
				buf.writeByte(((Byte)data.getData()).byteValue());
				break;
			case 1:
				buf.writeShort(((Short)data.getData()).shortValue());
				break;
			case 2:
				buf.writeInt(((Integer)data.getData()).intValue());
				break;
			case 3:
				buf.writeFloat(((Float)data.getData()).floatValue());
				break;
			case 4:
				buf.writeString((String)data.getData());
				break;
			case 5:
				Stack stack = (Stack)data.getData();
				buf.writeStack(stack);
				break;
			case 6:
				Vec3 vec = (Vec3)data.getData();
				buf.writeInt(vec.getX());
				buf.writeInt(vec.getY());
				buf.writeInt(vec.getZ());
				break;
			case 7:
				Vec3f vecf = (Vec3f)data.getData();
				buf.writeFloat(vecf.getX());
				buf.writeFloat(vecf.getY());
				buf.writeFloat(vecf.getZ());
		}
	}

	public static void writeData(List<EntityData> list, PacketBuffer buf) throws IOException {
		if(list != null) {
			for(EntityData data : list) {
				EntityData.writeData(buf, data);
			}
		}
		buf.writeByte(127);
	}

	public static List<EntityData> readData(PacketBuffer buf) throws IOException {
		List<EntityData> list = null;
		for(int value = buf.readByte(); value != 127; value = buf.readByte()) {
			if(list == null)
				list = Lists.<EntityData>newArrayList();
			int type = (value & 224) >> 5;
			int id = value & 31;
			EntityData data = null;
			switch(type) {
				case 0:
					data = new EntityData(type, id, Byte.valueOf(buf.readByte()));
					break;
				case 1:
					data = new EntityData(type, id, Short.valueOf(buf.readShort()));
					break;
				case 2:
					data = new EntityData(type, id, Integer.valueOf(buf.readInt()));
					break;
				case 3:
					data = new EntityData(type, id, Float.valueOf(buf.readFloat()));
					break;
				case 4:
					data = new EntityData(type, id, buf.readStringFromBuffer(32767));
					break;
				case 5:
					data = new EntityData(type, id, buf.readStack());
					break;
				case 6:
					int x = buf.readInt();
					int y = buf.readInt();
					int z = buf.readInt();
					data = new EntityData(type, id, new Vec3(x, y, z));
					break;
				case 7:
					float xf = buf.readFloat();
					float yf = buf.readFloat();
					float zf = buf.readFloat();
					data = new EntityData(type, id, new Vec3f(xf, yf, zf));
			}
			list.add(data);
		}
		return list;
	}

	public EntityData(int type, int id, Object data) {
		this.type = type;
		this.id = id;
		this.data = data;
	}

	public int getType() {
		return this.type;
	}

	public int getId() {
		return this.id;
	}

	public Object getData() {
		return this.data;
	}
}