package proxy.util;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonArray;
import com.google.gson.JsonObject;

import proxy.Proxy;

import java.util.UUID;

public class ServerInfo {
	private static final Gson GSON = new GsonBuilder().create();
	
	private final String name;
	private final int protocol;
	
	private String motd = "";
	private int capacity;
	private int online;
	private Profile[] list;
	private String icon;

	public ServerInfo(String name, int protocol) {
		this.name = name;
		this.protocol = protocol;
	}

	public void setMotd(String motd) {
		this.motd = motd;
	}

	public void setCapacity(int capacity) {
		this.capacity = capacity;
	}

	public void setOnline(int online) {
		this.online = online;
	}

	public void setList(String[] lines) {
		if(lines == null) {
			this.list = null;
		}
		else {
			this.list = new Profile[Math.min(lines.length, 12)];
			for(int z = 0; z < this.list.length; z++) {
				this.list[z] = new Profile(Proxy.getOfflineUUID(lines[z]), lines[z]);
			}
		}
	}

	public void setIcon(String icon) {
		this.icon = icon;
	}

	public String serialize() {
		JsonObject obj = new JsonObject();
		obj.addProperty("description", this.motd == null ? "" : this.motd);
		JsonObject info = new JsonObject();
		info.addProperty("max", this.capacity);
		info.addProperty("online", this.online);
		if(this.list != null && this.list.length > 0) {
			JsonArray arr = new JsonArray();
			for(int z = 0; z < this.list.length; z++) {
				JsonObject profile = new JsonObject();
				UUID id = this.list[z].getId();
				profile.addProperty("id", id == null ? "" : id.toString());
				profile.addProperty("name", this.list[z].getName());
				arr.add(profile);
			}
			info.add("sample", arr);
		}
		obj.add("players", info);
		JsonObject version = new JsonObject();
		version.addProperty("name", this.name);
		version.addProperty("protocol", this.protocol);
		obj.add("version", version);
		if(this.icon != null)
			obj.addProperty("favicon", this.icon);
		return GSON.toJson(obj);
	}
}
