package proxy.util;

import java.nio.charset.Charset;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;

public class User {
	private static final Charset UTF_8 = Charset.forName("UTF-8");
	
	protected final String username;
	
	private byte[] hash;
	private byte[] salt;
	protected boolean admin;
	
	public User(String username) {
		this.username = username;
	}
	
	public void setPassword(byte[] hash, byte[] salt) {
		this.hash = hash;
		this.salt = salt;
	}
	
	public String getUsername() {
		return this.username;
	}
	
	public boolean checkPassword(String password) {
		return MessageDigest.isEqual(hashPassword(password, this.salt), this.hash);
	}
	
	public boolean isAdmin() {
		return this.admin;
	}
	
	public void setAdmin(boolean admin) {
		this.admin = admin;
	}
	
	public boolean isOnline() {
		return false;
	}
	
	public void copyFrom(User user) {
		this.hash = user.hash;
		this.salt = user.salt;
		this.admin = user.admin;
	}
	
	private static byte[] hashPassword(String pass, byte[] salt) {
		try {
			MessageDigest digest = MessageDigest.getInstance("SHA-512");
			digest.update(pass.getBytes(UTF_8));
			digest.update(salt);
			return digest.digest();
		}
		catch(NoSuchAlgorithmException e) {
			Log.error("Could not generate password hash");
			return null;
		}
	}
	
	public static User createUser(String user, String pass) {
		SecureRandom rand = new SecureRandom();
		byte[] salt = new byte[32];
		rand.nextBytes(salt);
		User usr = new User(user);
		usr.setPassword(hashPassword(pass, salt), salt);
		return usr;
	}
}
